/*
 * Support Vector Registration (SVR): svr_rigid_cost_function
 * L2 cost function for rigid registration. Required for VNL LBFGSB optimiser.
 * 
 * Campbell, D., and Petersson, L., “An Adaptive Data Representations for
 * Robust Point-Set Registration and Merging”, International Conference on
 * Computer Vision (ICCV), Santiago, Chile, IEEE, Dec. 2015
 * 
 * For the full license, see license.txt in the root directory
 * 
 * Author: Dylan Campbell
 * Date: 20150820
 * Revision: 1
 */

#ifndef SVR_RIGID_COST_FUNCTION_H_
#define SVR_RIGID_COST_FUNCTION_H_

#include <vnl/vnl_cost_function.h>
#include "svr.h"

class SVR; // Forward declare SVR class

class SVRRigidCostFunction : public vnl_cost_function
{
public:
	// Constructors
	SVRRigidCostFunction();

	// Destructors
	~SVRRigidCostFunction() {}

	// Accessors
  int dimension() const {return dimension_;}
  double sigma() const {return sigma_;}
  vnl_matrix<double> gradient() const {return gradient_;}
  SVR* svr() const {return svr_;}

	// Mutators
  void set_dimension(int dimension) {dimension_ = dimension;}
	void set_sigma(double sigma) {sigma_ = sigma;}
	void set_gradient(vnl_matrix<double> gradient) {gradient_ = gradient;}
	void set_svr(SVR* svr) {svr_ = svr;}
	void set_svgm(SVGM* svgm) {svgm_ = svgm;}

	// Class Functions
	void Initialise(SVR* svr, SVGM* svgm);
	double f(const vnl_vector<double>& theta);
  void gradf(const vnl_vector<double>& theta, vnl_vector<double>& fgrad);

private:
  int dimension_;
  double sigma_;
  vnl_matrix<double> gradient_;
  SVR* svr_;
  SVGM* svgm_;
};

#endif /* SVR_RIGID_COST_FUNCTION_H_ */
