%% Support Vector Registration (SVR): demo
% Script to demonstrate the SVR algorithm
%
% Campbell, D., and Petersson, L., “An Adaptive Data Representations for
% Robust Point-Set Registration and Merging”, International Conference on
% Computer Vision (ICCV), Santiago, Chile, IEEE, Dec. 2015
%
% For the full license, see license.txt in the root directory
%
% Author: Dylan Campbell
% Date: 20150709
% Revision: 1

addpath(genpath('../'));

%% 3D
file_name_scene = 'dragonA.txt';
file_name_model = 'dragonB.txt';

[theta, durations] = svr(file_name_scene, file_name_model, @config);

% Print results
disp('theta {rx, ry, rz, rw, tx, ty, tz}:');
disp(theta);
disp('durations (s) {SVM1, SVM2, SVR}:');
disp(durations);

% Load point-sets
S = load(file_name_scene, '-ascii');
M = load(file_name_model, '-ascii');

% Transform model by parameters
Mt = transformPointset(M, 'rigid3d', theta);

% Display point-sets
figure(1); clf; set(gcf, 'name', '3D Rigid Support Vector Registration');
subplot(1,2,1); hold on; axis equal; axis off;
plot3(M(:,1),M(:,2),M(:,3),'r.', 'MarkerSize', 5);
plot3(S(:,1),S(:,2),S(:,3),'k.', 'MarkerSize', 5);
title('Initial Pose');
subplot(1,2,2); hold on; axis equal; axis off;
plot3(Mt(:,1),Mt(:,2),Mt(:,3),'r.', 'MarkerSize', 5);
plot3(S(:,1),S(:,2),S(:,3),'k.', 'MarkerSize', 5);
title('Final Pose');
rotate3d;

%% 2D
file_name_scene = 'fishA.txt';
file_name_model = 'fishB.txt';

[theta, durations] = svr(file_name_scene, file_name_model, @config2d);

% Print results
disp('theta {tx, ty, r}:');
disp(theta);
disp('durations (s) {SVM1, SVM2, SVR}:');
disp(durations);

% Load point-sets
S = load(file_name_scene, '-ascii');
M = load(file_name_model, '-ascii');

% Transform model by parameters
Mt = transformPointset(M, 'rigid2d', theta);

% Display point-sets
figure(2); clf; set(gcf, 'name', '2D Rigid Support Vector Registration');
subplot(1,2,1); hold on; axis equal; axis off;
plot(M(:,1),M(:,2),'r.', 'MarkerSize', 5);
plot(S(:,1),S(:,2),'k.', 'MarkerSize', 5);
title('Initial Pose');
subplot(1,2,2); hold on; axis equal; axis off;
plot(Mt(:,1),Mt(:,2),'r.', 'MarkerSize', 5);
plot(S(:,1),S(:,2),'k.', 'MarkerSize', 5);
title('Final Pose');