// Support Vector Registration (SVR): GaussTransformWrapper
// Matlab MEX Wrapper for Gauss Transform function
// 
// Campbell, D., and Petersson, L., “An Adaptive Data Representations for
// Robust Point-Set Registration and Merging”, International Conference on
// Computer Vision (ICCV), Santiago, Chile, IEEE, Dec. 2015
// 
// For the full license, see license.txt in the root directory
// 
// Author: Dylan Campbell
// Date: 20150709
// Revision: 5

#include "mex.h"

double GaussTransform(double* X, double* Y, double* phiX, double* phiY, int m, int n, int dim, double scale, double* gradient);

void mexFunction(int nlhs, mxArray *plhs[], int nrhs, const mxArray *prhs[])
{
    int m, n, dim;
    double *X, *Y, *phiX, *phiY, *fval, *gradient, scale;
    
    /* Check for proper number of input and output arguments */    
    if(nrhs != 5) {
        mexErrMsgTxt("Five input arguments required.");
    } 
    if(nlhs > 2){
        mexErrMsgTxt("Too many output arguments.");
    }
    
    /* Check data type of input argument */
    if(!(mxIsDouble(prhs[0]))) {
      mexErrMsgTxt("Input array must be of type double.");
    }
    if(!(mxIsDouble(prhs[1]))) {
      mexErrMsgTxt("Input array must be of type double.");
    }
    if(!(mxIsDouble(prhs[2]))) {
      mexErrMsgTxt("Input array must be of type double.");
    }
    if(!(mxIsDouble(prhs[3]))) {
      mexErrMsgTxt("Input array must be of type double.");
    }
    if(!(mxIsDouble(prhs[4]))) {
      mexErrMsgTxt("Input array must be of type double.");
    }
    
    /* Copy data pointers */
    X = (double *)mxGetPr(prhs[0]);
    Y = (double *)mxGetPr(prhs[1]);
    phiX = (double *)mxGetPr(prhs[2]);
    phiY = (double *)mxGetPr(prhs[3]);
    scale = mxGetScalar(prhs[4]);

  	/* Get the dimensions of the matrix input X & Y */
  	m = mxGetN(prhs[0]);
  	n = mxGetN(prhs[1]);
  	dim = mxGetM(prhs[0]);
  	if(mxGetM(prhs[1]) != dim)
    {
  		mexErrMsgTxt("The two input point sets must have the same dimension.");
  	}
    
    /* Allocate space for the return argument */
    plhs[0] = mxCreateDoubleMatrix(1, 1, mxREAL); // fval
    plhs[1] = mxCreateDoubleMatrix(dim, m, mxREAL); // fgrad
    fval = mxGetPr(plhs[0]);
    gradient = mxGetPr(plhs[1]);
    
    *fval = GaussTransform(X, Y, phiX, phiY, m, n, dim, scale, gradient);
}
